/*
 * Copyright (C) 2009 Michael Lamothe
 *
 * This file is part of Me TV
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */
 
#ifndef __STRING_SPLITTER__
#define __STRING_SPLITTER__

#include <me-tv.h>

class StringSplitter
{
private:
	gchar** parts;
	gsize	count;
public:
	StringSplitter(const Glib::ustring& text, const char* delimiter,
		gboolean squeeze_repeats, gsize max_length);
	~StringSplitter();

	const gchar* get_value(guint index);
	gint get_int_value(guint index);	
	gsize get_count() const;
};

#endif
